diff --git a/web/pgadmin/browser/server_groups/__init__.py b/web/pgadmin/browser/server_groups/__init__.py
index 97a6ef5..31dcfe9 100644
--- a/web/pgadmin/browser/server_groups/__init__.py
+++ b/web/pgadmin/browser/server_groups/__init__.py
@@ -28,13 +28,14 @@ class ServerGroupModule(BrowserPluginModule):
     def get_nodes(self, *arg, **kwargs):
         """Return a JSON document listing the server groups for the user"""
         groups = ServerGroup.query.filter_by(user_id=current_user.id)
-        for group in groups:
+        for idx, group in enumerate(groups):
             yield self.generate_browser_node(
                     "%d" % (group.id), None,
                     group.name,
                     "icon-%s" % self.node_type,
                     True,
-                    self.node_type
+                    self.node_type,
+                    can_delete=True if idx > 0 else False
                     )
 
     @property
@@ -108,7 +109,8 @@ class ServerGroupView(NodeView):
         """Delete a server group node in the settings database"""
 
         # if server group id is 1 we won't delete it.
-        if gid == 1:
+        first_group = ServerGroup.query.filter_by(user_id=current_user.id).first()
+        if first_group.id == gid:
             return make_json_response(
                     status=417,
                     success=0,
@@ -225,7 +227,8 @@ class ServerGroupView(NodeView):
                             sg.name,
                             "icon-%s" % self.node_type,
                             True,
-                            self.node_type
+                            self.node_type,
+                            can_delete=True     # This is user created hence can deleted
                             )
                         )
             except Exception as e:
diff --git a/web/pgadmin/browser/server_groups/templates/server_groups/server_groups.js b/web/pgadmin/browser/server_groups/templates/server_groups/server_groups.js
index acb94a6..4221280 100644
--- a/web/pgadmin/browser/server_groups/templates/server_groups/server_groups.js
+++ b/web/pgadmin/browser/server_groups/templates/server_groups/server_groups.js
@@ -49,10 +49,10 @@ function($, _, pgAdmin, Backbone) {
         }
       }),
       canDrop: function(itemData, item, data) {
-        if(itemData._id == 1) {
-          return false;
+        if(itemData.can_delete) {
+          return true;
         }
-        return true;
+        return false;
       },
       canDelete: function(i) {
         var s = pgAdmin.Browser.tree.siblings(i, true);
